@@ -17,11 +17,11 @@ from importlib import import_module
 from importlib.util import MAGIC_NUMBER
 from pathlib import Path
 from typing import TYPE_CHECKING, Any
-from zipfile import ZIP_DEFLATED, ZIP_STORED, PyZipFile, ZipInfo
+from zipfile import ZIP_DEFLATED, ZIP_STORED, PyZipFile, ZipFile, ZipInfo
 
 from setuptools import Distribution
 
-from cx_Freeze._compat import IS_MACOS, IS_MINGW, IS_WINDOWS
+from cx_Freeze._compat import IS_CONDA, IS_MACOS, IS_MINGW, IS_WINDOWS
 from cx_Freeze.common import get_resource_file_path, process_path_specs
 from cx_Freeze.exception import FileError, OptionError
 from cx_Freeze.executable import Executable
@@ -65,7 +65,7 @@ class Freezer:
         excludes: list[str] | None = None,
         packages: list[str] | None = None,
         replace_paths: list[str] | None = None,
-        compress: bool = True,
+        compress: bool | None = True,
         optimize: int = 0,
         path: list[str | Path] | None = None,
         target_dir: str | Path | None = None,
@@ -80,6 +80,7 @@ class Freezer:
         include_msvcr: bool = False,
         zip_include_packages: Sequence[str] | None = None,
         zip_exclude_packages: Sequence[str] | None = None,
+        zip_filename: Path | str | None = None,
     ) -> None:
         self.executables: list[Executable] = self._validate_executables(
             executables
@@ -91,7 +92,7 @@ class Freezer:
         self.excludes: list[str] = list(excludes or [])
         self.packages: set[str] = set(packages or [])
         self.replace_paths: list[str] = list(replace_paths or [])
-        self.compress = True if compress is None else compress
+        self.compress: bool = True if compress is None else compress
         self.optimize: int = int(optimize or 0)
         self.path: list[str] | None = self._validate_path(path)
         self.include_msvcr: bool = bool(include_msvcr)
@@ -118,6 +119,13 @@ class Freezer:
         self.zip_include_all_packages: bool = False
         self._populate_zip_options(zip_include_packages, zip_exclude_packages)
 
+        self.zip_filename: Path | None = None
+        if zip_filename is None and self.compress:
+            zip_filename = "library"
+        if zip_filename:
+            zip_filename = Path(zip_filename).with_suffix(".zip").name
+            self.zip_filename = self.target_dir / "lib" / zip_filename
+
         self._verify_configuration()
 
         self._symlinks: set[tuple[Path, Path, bool]] = set()
@@ -135,7 +143,7 @@ class Freezer:
             platform = sysconfig.get_platform()
             python_version = sysconfig.get_python_version()
             path = f"build/exe.{platform}-{python_version}"
-        path = Path(path).resolve()
+        path = Path(os.path.abspath(path)).resolve()
         if os.fspath(path) in self.path:
             msg = "the build_exe directory cannot be used as search path"
             raise OptionError(msg)
@@ -232,21 +240,19 @@ class Freezer:
         the source of a symbolic link is copied by deferring the creation of
         the link.
         """
+        real_source = source.resolve()
         if source.is_symlink():
-            real_source = source.resolve()
             try:
-                symlink = real_source.relative_to(source.parent)
-            except ValueError:
-                symlink = Path(
-                    os.path.relpath(real_source, source.parent.resolve())
-                )
+                symlink = source.readlink()
+            except AttributeError:
+                symlink = Path(os.readlink(source))  # python 3.8
             real_target = target.with_name(symlink.name)
             if self.silent < 1:
                 print(f"[delay] linking {target} -> {symlink}")
             self._symlinks.add((target, symlink, real_source.is_dir()))
             # return the real source to be copied
             return real_source, real_target
-        return source, target
+        return real_source, target
 
     @abstractmethod
     def _post_copy_hook(
@@ -493,7 +499,7 @@ class Freezer:
         """Returns valid search path for modules, and fix the path for built-in
         modules when it differs from the running python built-in modules.
         """
-        path = list(map(os.fspath, path or sys.path))
+        path = list(map(os.path.normpath, path or sys.path))
         dynload = get_resource_file_path("bases", "lib-dynload", "")
         if dynload and dynload.is_dir():
             # add bases/lib-dynload to the finder path, if has modules
@@ -505,7 +511,7 @@ class Freezer:
                     with suppress(ValueError, IndexError):
                         index = path.index(dest_shared)
                         path.pop(index)
-                path.insert(index, os.fspath(dynload))
+                path.insert(index, os.path.normpath(dynload))
         return path
 
     @staticmethod
@@ -578,7 +584,8 @@ class Freezer:
         self.zip_exclude_packages = zip_exclude_packages
         self.zip_include_all_packages = zip_include_all_packages
 
-    def _write_modules(self, filename: Path) -> None:
+    def _write_modules(self) -> None:
+        filename: Path = self.target_dir / "lib" / "library.zip"
         finder: ModuleFinder = self.finder
         cache_path = finder.cache_path
 
@@ -725,18 +732,36 @@ class Freezer:
             finally:
                 os.environ["PATH"] = orig_path
 
+        # put all files in file system or keep in zip file
+        if self.zip_filename is None:
+            with ZipFile(filename) as outfile:
+                outfile.extractall(target_lib_dir)
+            filename.unlink()
+        else:
+            if self.zip_filename.name != filename.name:
+                # zip_filename differs from default
+                filename.rename(self.zip_filename)
+            library_data = self.target_dir / "lib" / "library.dat"
+            library_data.write_bytes(self.zip_filename.name.encode())
+
     def freeze(self) -> None:
         """Do the freeze."""
         finder: ModuleFinder = self.finder
 
         # Add the executables to target
-        for executable in self.executables:
+        for i, executable in enumerate(self.executables):
             self._freeze_executable(executable)
+            finder.add_constant(
+                f"_EXECUTABLE_NAME_{i}", executable.target_name
+            )
+        finder.add_constant("_EXECUTABLES_NUMBER", len(self.executables))
 
-        # Write the modules
+        # Write the modules baefore the included files to fix an issue
+        if IS_WINDOWS and not IS_CONDA:
+            self._write_modules()
+
+        # Include user-defined files and hooks-defined files
         target_dir = self.target_dir
-        self._write_modules(target_dir / "lib" / "library.zip")
-
         excluded_dependent_files = finder.excluded_dependent_files
         for source_path, target_path in finder.included_files:
             copy_dependent_files = source_path not in excluded_dependent_files
@@ -761,6 +786,10 @@ class Freezer:
                 fulltarget = target_dir / target_path
                 self._copy_file(source_path, fulltarget, copy_dependent_files)
 
+        # Write the modules after the included files to avoid duplicate files
+        if not (IS_WINDOWS and not IS_CONDA):
+            self._write_modules()
+
         # do any platform-specific post-Freeze work
         self._post_freeze_hook()
 
@@ -938,8 +967,8 @@ class WinFreezer(Freezer, PEParser):
                             dependent_target = Path(*parts) / dependent_name
                         except ValueError:
                             dependent_target = target_dir / dependent_name
-                # check to make sure the dependency is in the correct place
-                # because it can be outside of the python subtree
+                # make sure the dependency is in the correct directory because
+                # it cannot be outside the library_dir directory subtree
                 try:
                     dependent_target.relative_to(library_dir)
                 except ValueError:
@@ -1211,42 +1240,44 @@ class LinuxFreezer(Freezer, ELFParser):
             copy_dependent_files
             and source not in self.finder.excluded_dependent_files
         ):
-            library_dir = self.target_dir / "lib"
             source_dir = source.parent
             target_dir = target.parent
             fix_rpath = set()
-            for dependent_file in self.get_dependent_files(source):
-                if not self._should_copy_file(dependent_file):
+            for dependent in self.get_dependent_files(source):
+                if not self._should_copy_file(dependent):
                     continue
+                dependent_file = dependent.resolve()
+                # put the dependency (relatively) in the target_dir subtree
+                # this is possible with most packages installed by pip
+                dependent_name = dependent_file.name
                 try:
                     relative = dependent_file.relative_to(source_dir)
                 except ValueError:
-                    # put it in the target_dir if not already copied
-                    dependent_filename = dependent_file.name
-                    dependent_target = target_dir / dependent_filename
-                    relative = Path(dependent_filename)
-                    if dependent_target not in self.files_copied:
-                        for file in self.files_copied:
-                            if file.name == dependent_filename:
-                                relative = file.relative_to(library_dir)
-                                dependent_target = library_dir / relative
-                                break
+                    # put the dependency in target_dir along with the binary
+                    # file being copied, unless the dependency has already been
+                    # copied to another location and is relative to the source
+                    dependent_target = target_dir / dependent_name
+                    relative = Path(dependent_name)
+                    for file in self.files_copied:
+                        if file.name == dependent_name:
+                            try:
+                                relative = file.relative_to(target_dir)
+                            except ValueError:
+                                relative = Path(
+                                    os.path.relpath(file, target_dir)
+                                )
+                            else:
+                                dependent_target = file
+                            break
                 else:
                     dependent_target = target_dir / relative
-                    dependent_target = dependent_target.resolve()
-                    try:
-                        dependent_target.relative_to(library_dir)
-                    except ValueError:
-                        parts = list(relative.parts)
-                        while parts[0] == os.pardir:
-                            parts.pop(0)
-                        relative = Path(*parts)
-                        dependent_target = library_dir / relative
                 dep_libs = os.fspath(relative.parent)
                 fix_rpath.add(dep_libs)
                 self._copy_file(
                     dependent_file, dependent_target, copy_dependent_files
                 )
+                if dependent.name != dependent_name:
+                    self.replace_needed(target, dependent.name, dependent_name)
             if fix_rpath:
                 has_rpath = self.get_rpath(target)
                 rpath = ":".join(f"$ORIGIN/{r}" for r in fix_rpath)
